@@ -48,7 +48,7 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '0.1.9'; }
+	function GetVersion() { return '0.2'; }
 	function GetHelp() { return $this->Lang('help'); }
 	function GetAuthor() { return 'AireLibre'; }
 	function GetAuthorEmail() { return 'contact@airelibre.fr'; }
@@ -122,6 +122,7 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
 		$this->SetParameterType('detailtemplate', CLEAN_STRING);
 		$this->SetParameterType('registrationtemplate', CLEAN_STRING);
+		$this->SetParameterType('registrationslisttemplate', CLEAN_STRING);
 	}
 	
 	function SetParameters()
@@ -143,6 +144,7 @@ class EventsManager extends CGExtensions
 		$this->CreateParameter('summarytemplate', '', $this->Lang('param_summarytemplate'));
 		$this->CreateParameter('detailtemplate', '', $this->Lang('param_detailtemplate'));
 		$this->CreateParameter('registrationtemplate', '', $this->Lang('param_registrationtemplate'));
+		$this->CreateParameter('registrationslisttemplate', '', $this->Lang('param_registrationslisttemplate'));
 	}
 	
 	function InitializeAdmin()
