@@ -107,10 +107,12 @@ $lang['displayed_feu_properties'] = "FEU properties displayed in the registratio
 $lang['summarytemplates'] = 'Summary templates';
 $lang['detailtemplates'] = 'Detail templates';
 $lang['registrationtemplates'] = "Registration templates";
+$lang['registrationslisttemplates'] = "FE Registrations list templates";
 
 $lang['summarytemplate_addedit'] = "Add / Edit an events summary template";
 $lang['detailtemplate_addedit'] = "Add / Edit an event details template";
 $lang['registrationtemplate_addedit'] = "Add / Edit an event registration form template";
+$lang['registrationslisttemplate_addedit'] = "Add / Edit a frontend registrations list template";
 
 # Help with params
 $lang['param_action'] = "Specify the behaviour of the module. Possible values are:
@@ -121,7 +123,7 @@ $lang['param_action'] = "Specify the behaviour of the module. Possible values ar
 </ul>
 ";
 
-$lang['param_event_id'] = "Useful only with the <em>detail</em> and <em>register</em> actions - Specifies the event to display / to register to";
+$lang['param_event_id'] = "Useful only with the <em>detail</em>, <em>register</em> and <em>registrationslist</em> actions - Specifies the event to which the action is linked";
 $lang['param_detailpage'] = "Page ID to use to display an event detail - If not filled, the current page, or the one defined in the preferences will be used";
 $lang['param_category_id'] = "Useful only with the <em>default</em> action, this parameter will be used to display only the events that are in the specified category id - You can use a comma seperated list to specify multiples categories IDs. Example : <em>category_id='2,3'</em>";
 $lang['param_category'] = "Useful only with the <em>default</em> action, this parameter will be used to display only the events that are in the specified category name - You can use a comma seperated list to specify multiples categories names. Example : <em>category_id='show,training'</em>";
@@ -153,7 +155,8 @@ $lang['param_start_datetime'] = "Useful only with the <em>default</em> action, a
 $lang['param_end_datetime'] = "Useful only with the <em>default</em> action, and only when show='custom', this parameter defines the end date and time of the events to be displayed. Date and time must be in standard format : YYYY-MM-DD HH:MM:SS - See the start_datetime param for examples";
 $lang['param_summarytemplate'] = "Useful only with the <em>default</em> action, this parameter specifies the template that should be used for the summary mode display. If no value is specified, the default template of that type is used";
 $lang['param_detailtemplate'] = "Useful only with the <em>detail</em> action, this parameter specifies the template that should be used for the detail mode display. If no value is specified, the default template of that type is used";
-$lang['param_registrationtemplate'] = "Useful only with the <em>register</em> action, this parameter specifies the template that should be used for the registrater mode display. If no value is specified, the default template of that type is used";
+$lang['param_registrationtemplate'] = "Useful only with the <em>register</em> action, this parameter specifies the template that should be used for the register form display. If no value is specified, the default template of that type is used";
+$lang['param_registrationslisttemplate'] = "Useful only with the <em>registrationslist</em> action, this parameter specifies the template that should be used for the registrations list display. If no value is specified, the default template of that type is used";
 $lang['param_myevents'] = "true/false - Useful only with the <em>default</em> action, with this parameter you can display only the events the current logged in FEUser is registered to. If no one is connected, this parameter is simply ignored - Tip: use this option on a private FEU page";
 $lang['param_sortby'] = "Useful only with the <em>default</em> action, this parameter specifies how to sort the events. Possible values:
 <ul>
@@ -182,6 +185,10 @@ $lang['help'] = "
 <p>Simply use the <strong>myevents</strong> parameter this way: <strong>{EventsManager myevents=true}</strong></p>
 <p>You can customize your templates with some parameters and options (see below)</p>
 
+<h3>Display the list of the registrations for an event</h3>
+<p>Simple use the <strong>registrationslist</strong> action like that : <strong>{EventsManager action='registrationslist' event_id=5}</strong> where <strong>event_id</strong> is the id of the event you want to display the registrations.</p>
+<p>You can customize your templates with some parameters and options (see below)</p>
+
 <h3>Support</h3>
 <p>This module does not include commercial support. However there are a number of resources available to help you with it:</p>
 <ul>
