@@ -111,6 +111,7 @@ $lang['registrationtemplates'] = "Gabarits d'inscription";
 $lang['summarytemplate_addedit'] = "Ajouter / Editer un gabarit de sommaire des événements ";
 $lang['detailtemplate_addedit'] = "Ajouter / Editer un gabarit de détail d'un événement ";
 $lang['registrationtemplate_addedit'] = "Ajouter / Editer un gabarit de formulaire d'inscription à un événement ";
+$lang['registrationslisttemplate_addedit'] = "Ajouter / Editer un gabarit de liste d'inscrits côté site";
 
 # Help with params
 $lang['param_action'] = "Définit le comportement du module. Les valeurs possibles sont :
@@ -120,7 +121,7 @@ $lang['param_action'] = "Définit le comportement du module. Les valeurs possibl
 	<li>register - Affiche le formulaire d'inscription à un évènement - Utilisez le paramètre event_id pour préciser l'évènement auquel s'inscrire</li>
 </ul>
 ";
-$lang['param_event_id'] = "Utilisé uniquement avec les actions <em>detail</em> et <em>register</em> - ID de l'événement à afficher / auquel s'inscrire";
+$lang['param_event_id'] = "Utilisé uniquement avec les actions <em>detail</em>, <em>register</em> et <em>registrationslist</em> - ID de l'événement auquel rattacher l'action";
 $lang['param_detailpage'] = "ID de la page à utiliser pour afficher le détail d'un évènement - Si non précisé, la page définie dans les préférences ou la page en cours est utilisée";
 $lang['param_category_id'] = "Utilisé uniquement avec l'action <em>default</em>, affiche les évènements liés à le ou les ID(s) de catégorie(s) spécifié(s) - Vous pouvez indiquer plusieurs ID en les séparant par des virgules. Exemple : <em>category_id='2,3'</em>";
 $lang['param_category'] = "Utilisé uniquement avec l'action <em>default</em>, affiche les évènements liés à le ou les nom(s) de catégorie(s) spécifié(s) - Vous pouvez indiquer plusieurs noms en les séparant par des virgules. Exemple : <em>category='Spectacles,Formations'</em>";
@@ -150,6 +151,7 @@ $lang['param_end_datetime'] = "Utilisé uniquement avec l'action <em>default</em
 $lang['param_summarytemplate'] = "Utilisé uniquement avec l'action <em>default</em>, vous permet de préciser le gabarit à utiliser pour l'affichage de la liste des évènements - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_detailtemplate'] = "Utilisé uniquement avec les actions <em>default</em> et <em>detail</em>, vous permet de préciser le gabarit à utiliser pour l'affichage d'un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_registrationtemplate'] = "Utilisé uniquement avec l'action <em>register</em>, vous permet de préciser le gabarit à utiliser pour l'affichage du formulaire d'inscription à un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
+$lang['param_registrationslisttemplate'] = "Utilisé uniquement avec l'action <em>registrationslist</em>, vous permet de préciser le gabarit à utiliser pour l'affichage de la liste des inscrits à un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_myevents'] = "true/false - Utilisé uniquement avec l'action <em>default</em>, affiche uniquement les évènements auxquels l'utilisateur FEU actuellement connecté est enregistré. Si personne n'est connecté, le paramètre est ignoré - Astuce : utilisez cette option sur une page de type 'Contenu protégé'";
 $lang['param_sortby'] = "Utilisé uniquement avec l'action <em>default</em>, cette option vous permet de définir un critère de tri des évènements. Valeurs possibles :
 <ul>
@@ -177,6 +179,11 @@ $lang['help'] = "
 <h3>Afficher uniquement les évènements auxquels l'utilisateur FEU connecté s'est enregistré</h3>
 <p>Utilisez simplement le paramètre <strong>myevents</strong> de cette manière : <strong>{EventsManager myevents=true}</strong></p>
 <p>Pour personnaliser d'avantage votre liste d'évènements, consultez la liste des options disponibles en bas de cette page. Vous pouvez aussi personnaliser vos gabarits d'affichage grâce à Smarty.</p>
+
+<h3>Afficher la liste des inscriptions pour un évènement particulier</h3>
+<p>Utilisez simplement l'action <strong>registrationslist</strong> de cette manière : <strong>{EventsManager action='registrationslist' event_id=5}</strong> où <strong>id_event</strong> correspond à l'id de l'évènement pour lequel afficher les inscrits</p>
+<p>Pour personnaliser d'avantage votre liste d'évènements, consultez la liste des options disponibles en bas de cette page. Vous pouvez aussi personnaliser vos gabarits d'affichage grâce à Smarty.</p>
+
 <h3>Assistance</h3>
 <p>Ce module est fourni sans aucune assistance commerciale. Cependant,
 vous pouvez tout de même obtenir de l'aide :</p>
