@@ -37,7 +37,29 @@ class EventsManager_registration extends EventsManager_object
 		}
 		else
 			parent::__construct($id, $load_fields);
+		
+		if ($this->id_user)
+			$this->load_user();
 	}
+	
+	// Load the user with the properties
+	public function load_user()
+	{
+		$this->user = new EventsManager_user($this->id_user);
+	}
+	
+	// Smarty object with the user
+	public function get_smarty_object()
+	{
+		if (!$this->user)
+			$this->load_user();
+		
+		$obj = parent::get_smarty_object();
+		$obj->user = $this->user;
+		
+		return $obj;
+	}
+	
 }
 
 ?>
\ No newline at end of file
